==> owncloud-8.1.0p2.tgz: owncloud/apps/encryption/l10n/zh_CN.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "丢失的回复密钥",
    "Please repeat the recovery key password" : "请替换恢复密钥",
    "Recovery key successfully enabled" : "恢复密钥成功启用",
    "Could not enable recovery key. Please check your recovery key password!" : "不能启用恢复密钥。请检查恢复密钥密码！",
    "Recovery key successfully disabled" : "恢复密钥成功禁用",
    "Could not disable recovery key. Please check your recovery key password!" : "不能禁用恢复密钥。请检查恢复密钥密码！",
    "Please provide the old recovery password" : "请提供原来的恢复密码",
    "Please provide a new recovery password" : "请提供一个新的恢复密码",
    "Please repeat the new recovery password" : "请替换新的恢复密码",
    "Password successfully changed." : "密码修改成功。",
    "Could not change the password. Maybe the old password was not correct." : "不能修改密码。旧密码可能不正确。",
    "Could not update the private key password." : "不能更新私有密钥。",
    "The old password was not correct, please try again." : "原始密码错误，请重试。",
    "Private key password successfully updated." : "私钥密码成功更新。",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "无效的私有密钥。请到您的个人配置里去更新私有密钥，来恢复对加密文件的访问。",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "加密应用被启用了，但是你的加密密钥没有初始化，请重新登出登录系统一次。",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : " 无法解密这个文件（或许这是一个共享文件？），请询问文件所有者重新与您分享这个文件。",
    "Recovery key password" : "恢复密钥密码",
    "Change recovery key password:" : "更改恢复密钥密码",
    "Change Password" : "修改密码",
    " If you don't remember your old password you can ask your administrator to recover your files." : "如果您记不住旧的密码，您可以请求管理员恢复您的文件。",
    "Old log-in password" : "旧登录密码",
    "Current log-in password" : "当前登录密码",
    "Update Private Key Password" : "更新私钥密码",
    "Enable password recovery:" : "启用密码恢复：",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "启用该项将允许你在密码丢失后取回您的加密文件",
    "Enabled" : "开启",
    "Disabled" : "禁用"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.10.tgz: owncloud/apps/encryption/l10n/zh_CN.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "丢失的回复密钥",
    "Please repeat the recovery key password" : "请替换恢复密钥",
    "Recovery key successfully enabled" : "恢复密钥成功启用",
    "Could not enable recovery key. Please check your recovery key password!" : "不能启用恢复密钥。请检查恢复密钥密码！",
    "Recovery key successfully disabled" : "恢复密钥成功禁用",
    "Could not disable recovery key. Please check your recovery key password!" : "不能禁用恢复密钥。请检查恢复密钥密码！",
    "Missing parameters" : "缺少参数",
    "Please provide the old recovery password" : "请提供原来的恢复密码",
    "Please provide a new recovery password" : "请提供一个新的恢复密码",
    "Please repeat the new recovery password" : "请替换新的恢复密码",
    "Password successfully changed." : "密码修改成功。",
    "Could not change the password. Maybe the old password was not correct." : "不能修改密码。旧密码可能不正确。",
    "Could not update the private key password." : "不能更新私有密钥。",
    "The old password was not correct, please try again." : "原始密码错误，请重试。",
    "The current log-in password was not correct, please try again." : "当前登录密码不正确，请重试。",
    "Private key password successfully updated." : "私钥密码成功更新。",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "无效的私有密钥。请到您的个人配置里去更新私有密钥，来恢复对加密文件的访问。",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : " 无法解密这个文件（或许这是一个共享文件？），请询问文件所有者重新与您分享这个文件。",
    "The share will expire on %s." : "此分享将在 %s 过期。",
    "Cheers!" : "干杯！",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "加密应用被启用了，但是你的加密密钥没有初始化，请重新登出登录系统一次。",
    "Recovery key password" : "恢复密钥密码",
    "Change recovery key password:" : "更改恢复密钥密码",
    "Change Password" : "修改密码",
    " If you don't remember your old password you can ask your administrator to recover your files." : "如果您记不住旧的密码，您可以请求管理员恢复您的文件。",
    "Old log-in password" : "旧登录密码",
    "Current log-in password" : "当前登录密码",
    "Update Private Key Password" : "更新私钥密码",
    "Enable password recovery:" : "启用密码恢复：",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "启用该项将允许你在密码丢失后取回您的加密文件",
    "Enabled" : "开启",
    "Disabled" : "禁用"
},
"nplurals=1; plural=0;");
